#include "simpleCal.h"

Calendar::Calendar(QWidget* parent) : QMainWindow(parent){
	// Set the window title
	setWindowTitle("Jonny's Calendar Thing!");
	
	// Add a central widget to this window which contains the rest of the widgets
	QWidget* centerWidget = new QWidget(this);
	setCentralWidget(centerWidget);
	
	// Set the layout of the central widget to be a vertical pile like thing
	QVBoxLayout* layout = new QVBoxLayout;
	centerWidget->setLayout(layout);
	
	// Add a calendar which watches where the user is clicking
	calendar = new QCalendarWidget(centerWidget);
	layout->addWidget(calendar);
	connect(calendar, SIGNAL(selectionChanged()), this, SLOT(datePicked()));
	
	// Add a label showing the current time
	timeLabel = new QLabel("The time is: [ERR:lolwut?]", centerWidget);
	layout->addWidget(timeLabel);
	
	// Create a timer to keep updating the time
	clockTimer = new QTimer(this);
	connect(clockTimer, SIGNAL(timeout()), this, SLOT(updateTime()));
	clockTimer->start(1000);
	updateTime();
	
	// Create a Quit button which calls this object's quit slot
	quitButton = new QPushButton("Quit", centerWidget);
	connect(quitButton, SIGNAL(clicked()), this, SLOT(close()));
	layout->addWidget(quitButton);
}

bool Calendar::close() {
	// Print a message to prove I'm able to override those pitiful built in
	// slots... *MWHAHAHAA* etc.
	std::cout << "The quit button was pressed, better do it..." << std::endl;
	
	return QMainWindow::close();
}

void Calendar::datePicked() {
	// Check if it is my birthday...
	QDate date = calendar->selectedDate();
	if (date.month() == 12 && date.day() == 11) {
		QMessageBox::information(this, "Just so you know...",
		                         "Hey, that's my birthday!");
	}
}

void Calendar::updateTime(){
	QTime currentTime = QTime::currentTime();
	
	QString newMessage("The time is: "
	                   + QString::number(currentTime.hour()) + ":"
	                   + QString::number(currentTime.minute()) + ":"
	                   + QString::number(currentTime.second()));
	timeLabel->setText(newMessage);
}
